package trask.app.life;

import java.awt.*;
import java.awt.event.*;
import java.util.*;

public class CalculationDetailsDisplay extends Frame
{
  private String[] temperatureStrings;
  private String[] harmonyStrings;
  private int displayPrecision = 2;

  public CalculationDetailsDisplay()
  {
    super("Calculation Details");
    setLayout(new GridBagLayout());

    addWindowListener(new WindowAdapter() {
      public void windowClosing(WindowEvent event) {
        setVisible(false);
      }});
  }

  public void setDisplayPrecision(int precision)
  {
    displayPrecision = precision;
  }

  public void setDetails(double[] temperature, double[] harmony, Vector[] subBlocks)
  {
    removeAll();

    GridBagConstraints constraints = new GridBagConstraints();

    constraints.gridy = 0;

    constraints.gridx = 0;
    add(new Label("SubBlock Dim"), constraints);

    constraints.gridx = 1;
    add(new Label("Temperature"), constraints);

    constraints.gridx = 2;
    add(new Label("Harmony"), constraints);

    double tenpow = Math.pow(10, displayPrecision);
    temperatureStrings = new String[subBlocks.length];
    harmonyStrings = new String[subBlocks.length];
    for (int i = 0; i < subBlocks.length; i++) {
      if (subBlocks[i] != null) {
        temperatureStrings[i] = "" + Math.round(temperature[i] * tenpow) / tenpow;
        harmonyStrings[i] = "" + Math.round(harmony[i] * tenpow) / tenpow;
        constraints.gridy++;

        constraints.gridx = 0;
        add(new Label(i + "x" + i), constraints);

        constraints.gridx = 1;
        add(new Label(temperatureStrings[i]), constraints);

        constraints.gridx = 2;
        add(new Label(harmonyStrings[i]), constraints);
      }
    }
    invalidate();
    validate();
    pack();
  }

  public void print(Graphics pg)
  {
    Font f = new Font("Monospaced", Font.PLAIN, 14);
    FontMetrics fm = getFontMetrics(f);
    pg.setFont(f);
    int x = 10;
    int y = 10;
    int dy = fm.getHeight();

    y += dy;
    StringBuffer blank = new StringBuffer("                                        ");
    blank.insert(7, "Temperature");
    blank.insert(23, "Harmony");
    pg.drawString(blank.toString(), x, y);
    y += dy / 2;
    for (int i = 0; i < temperatureStrings.length; i++) {
      if (temperatureStrings[i] != null) {
        y += dy;
        blank = new StringBuffer("                                        ");
        blank.insert(0, i + "x" + i + ":");
        blank.insert(11, temperatureStrings[i]);
        blank.insert(25, harmonyStrings[i]);
        pg.drawString(blank.toString(), x, y);
      }
    }

  }

}



