package trask.app.life;

import java.awt.*;
import java.awt.event.*;
import java.util.*;

public class LifeColorControl extends Container implements ItemListener
{
  private Color[] colors;
  private String[] labels;

  private Checkbox[] checkboxes;

  private int currentColorIndex = -1;

  private Vector colorChangeListeners = new Vector();

  public LifeColorControl()
  {

  }

  // get and set methods

  public void setColors(Color[] colrs)
  {
    colors = colrs;
  }

  public Color[] getColors()
  {
    return colors;
  }

  public void setLabels(String[] labls)
  {
    labels = labls;

    removeAll();
    checkboxes = new Checkbox[labels.length];
    setLayout(new GridLayout(checkboxes.length, 1));

    CheckboxGroup group = new CheckboxGroup();

    for (int i = 0; i < checkboxes.length; i++) {
      checkboxes[i] = new Checkbox(labels[i], false, group);
      checkboxes[i].addItemListener(this);
      add(checkboxes[i]);
    }
  }

  public String[] getLabels()
  {
    return labels;
  }

  public void setCurrentColorIndex(int index)
  {
    if (currentColorIndex == index) {
      return;
    }

    currentColorIndex = index;
    checkboxes[currentColorIndex].setState(true);

    fireColorChangeEvent(colors[currentColorIndex]);
  }

  public int getCurrentColorIndex()
  {
    return currentColorIndex;
  }

  // ColorChangeEvent methods

  public synchronized void addColorChangeListener(ColorChangeListener l)
  {
    colorChangeListeners.addElement(l);
  }

  public synchronized void removeColorChangeListener(ColorChangeListener l)
  {
    colorChangeListeners.removeElement(l);
  }

  public synchronized void fireColorChangeEvent(Color color)
  {
    ColorChangeEvent event = new ColorChangeEvent(this, color);

    for (Enumeration e = colorChangeListeners.elements(); e.hasMoreElements(); ) {
      ColorChangeListener l = (ColorChangeListener) e.nextElement();
      l.colorChanged(event);
    }
  }

  // ItemListener method

  public void itemStateChanged(ItemEvent event)
  {
    if (event.getStateChange() != ItemEvent.SELECTED) {
      System.out.println("Deselected");
      return;
    }

    for (int i = 0; i < checkboxes.length; i++) {
      if (event.getSource() == checkboxes[i]) {
        setCurrentColorIndex(i);
        break;
      }
    }
  }

}
